summaryrefslogtreecommitdiff
path: root/inc/common.php
diff options
context:
space:
mode:
Diffstat (limited to 'inc/common.php')
-rw-r--r--inc/common.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/inc/common.php b/inc/common.php
index 845ca3634..a477f26a1 100644
--- a/inc/common.php
+++ b/inc/common.php
@@ -437,9 +437,9 @@ function checkwordblock(){
//this is very bad performancewise and may even be too high still
$chunksize = 40;
}else{
//read file in chunks of 600 - this should work around the
//MAX_PATTERN_SIZE in modern PCRE
- $chunksize = 400;
+ $chunksize = 200;
}
while($blocks = array_splice($wordblocks,0,$chunksize)){
$re = array();
@@ -437,9 +437,9 @@ function checkwordblock(){
$chunksize = 40;
}else{
- //read file in chunks of 600 - this should work around the
+ //read file in chunks of 200 - this should work around the
//MAX_PATTERN_SIZE in modern PCRE